@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-2000 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2005 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: CatJob.cc,v 1.24 2002/07/12 09:55:01 lav Exp $ */
+/* $Id: CatJob.cc,v 1.27 2006/02/06 11:00:38 lav Exp $ */
 
 #include <config.h>
 #include "trio.h"
@@ -71,7 +71,7 @@ void CatJob::NextFile()
    FileCopy *copier=FileCopy::New(src_peer,dst_peer,false);
    copier->DontCopyDate();
 
-   if(ascii || (auto_ascii && !output->IsFiltered() && output->IsStdout()))
+   if(ascii || (auto_ascii && output->IsTTY()))
    {
       if(output->IsStdout())
 	 copier->LineBuffered();
@@ -101,7 +101,7 @@ CatJob::CatJob(FileAccess *new_session,OutputJob *_output,ArgV *new_args)
    {
       const char *pager=getenv("PAGER");
       if(pager==NULL)
-	 pager="exec more";
+	 pager=DEFAULT_PAGER;
       output->PreFilter(pager);
    }
    if(!strcmp(op,"zcat") || !strcmp(op,"zmore"))
@@ -124,4 +124,3 @@ void CatJob::ShowRunStatus(StatusLine *s)
       cp->ShowRunStatus(s);
    }
 }
-   
