@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: CmdExec.h,v 1.54 2005/08/03 07:12:44 lav Exp $ */
+/* $Id: CmdExec.h,v 1.57 2006/08/22 06:47:25 lav Exp $ */
 
 #ifndef CMDEXEC_H
 #define CMDEXEC_H
@@ -138,7 +138,8 @@ private:
 
    QueueFeeder *queue_feeder;
    CmdExec *GetQueue(bool create = true);
-   bool SameQueueParameters(CmdExec *);
+   bool SameQueueParameters(CmdExec *,const char *);
+   int max_waiting;
 
    FileAccess *saved_session;
    void ReuseSavedSession();
@@ -156,6 +157,7 @@ public:
    static bool is_space(char c) { return c==' ' || c=='\t'; }
    static bool is_quote(char c) { return c=='"' || c=='\''; }
    void FeedQuoted(const char *c);
+   void Exit(int);
    void AtExit();
    void EmptyCmds();
    bool WriteCmds(int fd) const;
@@ -248,6 +250,8 @@ public:
    void pre_stdout();
 
    void ChangeSlot(const char *n);
+
+   static CmdExec *top;
 };
 
 extern const char * const bookmark_subcmd[];
