@@ -18,13 +18,11 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileAccess.h,v 1.88 2006/04/19 09:48:03 lav Exp $ */
+/* $Id: FileAccess.h,v 1.93 2006/07/27 07:22:39 lav Exp $ */
 
 #ifndef FILEACCESS_H
 #define FILEACCESS_H
 
-#include "SMTask.h"
-#include "trio.h"
 #include <time.h>
 #include <sys/types.h>
 
@@ -38,14 +36,19 @@
 # include <poll.h>
 #endif
 
+#include "SMTask.h"
+#include "trio.h"
 #include "xmalloc.h"
 #include "ResMgr.h"
 #include "FileSet.h"
+#include "LsCache.h"
 
-#define NO_SIZE	     (-1L)
-#define NO_SIZE_YET  (-2L)
+#define NO_SIZE	     ((off_t)-1L)
+#define NO_SIZE_YET  ((off_t)-2L)
 #define NO_DATE	     ((time_t)-1L)
 #define NO_DATE_YET  ((time_t)-2L)
+#define FILE_END     ((off_t)-1L)
+#define UNKNOWN_POS  ((off_t)-1L)
 
 class ListInfo;
 class Glob;
@@ -57,6 +60,7 @@ class FileAccess : public SMTask
 {
    static bool class_inited;
 public:
+   static LsCache *cache;
    enum open_mode
    {
       CLOSED,
@@ -137,21 +141,18 @@ protected:
    int	 mode;
    off_t pos;
    off_t real_pos;
+   off_t limit;
 
    time_t *opt_date;
    off_t  *opt_size;
 
-   int	 Poll(int fd,int ev);
-   int   CheckHangup(struct pollfd *pfd,int num);
    static void NonBlock(int fd);
    static void CloseOnExec(int fd);
 
    void  DebugPrint(const char *prefix,const char *str,int level=9);
 
-   time_t   try_time;
-   time_t   event_time;
-   void BumpEventTime(time_t t);
-   int	 retries;
+   time_t try_time;
+   int retries;
 
    fileinfo *array_for_info;
    int	 array_ptr;
@@ -176,15 +177,13 @@ protected:
 	 ExpandTildeInCWD();
       }
 
-   char *url;
-
    off_t  entity_size; // size of file to be sent
    time_t entity_date; // date of file to be sent
 
    char *closure;
    const char *res_prefix;
-   ResValue Query(const char *name,const char *closure=0);
-   bool QueryBool(const char *name,const char *closure=0)
+   ResValue Query(const char *name,const char *closure=0) const;
+   bool QueryBool(const char *name,const char *closure=0) const
       {
 	 return Query(name,closure).to_bool();
       }
@@ -219,24 +218,24 @@ protected:
    virtual ~FileAccess();
 
 public:
-   virtual const char *GetProto() = 0; // http, ftp, file etc
-   bool SameProtoAs(FileAccess *fa) { return !strcmp(GetProto(),fa->GetProto()); }
-   virtual FileAccess *Clone() = 0;
+   virtual const char *GetProto() const = 0; // http, ftp, file etc
+   bool SameProtoAs(const FileAccess *fa) const { return !strcmp(GetProto(),fa->GetProto()); }
+   virtual FileAccess *Clone() const = 0;
    virtual const char *ProtocolSubstitution(const char *host) { return 0; }
 
-   const char *GetVisualProto() { return vproto?vproto:GetProto(); }
+   const char *GetVisualProto() const { return vproto?vproto:GetProto(); }
    void SetVisualProto(const char *p) { xfree(vproto); vproto=xstrdup(p); }
-   const char  *GetHome() { return home; }
-   const char  *GetHostName() { return hostname; }
-   const char  *GetUser() { return user; }
-   const char  *GetPassword() { return pass; }
-   const char  *GetPort() { return portname; }
-   const char  *GetConnectURL(int flags=0);
-   const char  *GetFileURL(const char *file,int flags=0);
+   const char  *GetHome() const { return home; }
+   const char  *GetHostName() const { return hostname; }
+   const char  *GetUser() const { return user; }
+   const char  *GetPassword() const { return pass; }
+   const char  *GetPort() const { return portname; }
+   const char  *GetConnectURL(int flags=0) const;
+   const char  *GetFileURL(const char *file,int flags=0) const;
    enum { NO_PATH=1,WITH_PASSWORD=2,NO_PASSWORD=4,NO_USER=8 };
 
-   virtual void Connect(const char *h,const char *p);
-   virtual void ConnectVerify();
+   void Connect(const char *h,const char *p);
+   void ConnectVerify();
    void PathVerify(const Path &);
    virtual void AnonymousLogin();
    virtual void Login(const char *u,const char *p);
@@ -246,6 +245,7 @@ public:
 
    virtual void Open(const char *file,int mode,off_t pos=0);
    void SetFileURL(const char *u);
+   void SetLimit(off_t lim) { limit=lim; }
    void SetSize(off_t s) { entity_size=s; }
    void SetDate(time_t d) { entity_date=d; }
    void WantDate(time_t *d) { opt_date=d; }
@@ -282,16 +282,16 @@ public:
    void SeekReal() { pos=GetRealPos(); }
    void RereadManual() { norest_manual=true; }
 
-   const Path& GetCwd() { return cwd; }
-   const Path& GetNewCwd() { return *new_cwd; }
-   const char *GetFile() { return file; }
+   const Path& GetCwd() const { return cwd; }
+   const Path& GetNewCwd() const { return *new_cwd; }
+   const char *GetFile() const { return file; }
 
    virtual int Do() = 0;
    virtual int Done() = 0;
 
-   virtual bool SameLocationAs(FileAccess *fa);
-   virtual bool SameSiteAs(FileAccess *fa);
-   virtual bool IsBetterThan(FileAccess *fa);
+   virtual bool SameLocationAs(const FileAccess *fa) const;
+   virtual bool SameSiteAs(const FileAccess *fa) const;
+   bool IsBetterThan(const FileAccess *fa) const;
 
    void Init();
    FileAccess() { Init(); }
@@ -303,7 +303,7 @@ public:
    bool	 IsOpen() { return !IsClosed(); }
    int	 OpenMode() { return mode; }
 
-   virtual int  IsConnected(); // level of connection (0 - not connected).
+   virtual int  IsConnected() const; // level of connection (0 - not connected).
    virtual void Disconnect();
    virtual void UseCache(bool);
    virtual bool NeedSizeDateBeforehand();
@@ -335,7 +335,7 @@ public:
    virtual ListInfo *MakeListInfo(const char *path=0);
    virtual Glob *MakeGlob(const char *pattern);
    virtual DirList *MakeDirList(ArgV *a);
-   virtual FileSet *ParseLongList(const char *buf,int len,int *err=0) { return 0; }
+   virtual FileSet *ParseLongList(const char *buf,int len,int *err=0) const { return 0; }
 
    static bool NotSerious(int err);
 
@@ -392,6 +392,7 @@ public:
    const char *GetLogContext() { return hostname; }
 
    static void ClassInit();
+   static void ClassCleanup();
 };
 
 class FileAccessOperation : public SMTask
@@ -444,14 +445,7 @@ public:
    void SetExclude(const char *p,PatternSet *e);
 
    // caller has to delete the resulting FileSet itself.
-   FileSet *GetResult()
-      {
-	 FileSet *tmp=result;
-      	 result=0;
-	 return tmp;
-	 // miss := (assign and return old value) :(
-      	 // return result:=0;
-      }
+   FileSet *GetResult() { return replace_value(result,(FileSet*)0); }
 
    void Need(unsigned mask) { need|=mask; }
    void NoNeed(unsigned mask) { need&=~mask; }
