@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileSet.cc,v 1.51 2006/07/27 07:44:53 lav Exp $ */
+/* $Id: FileSet.cc,v 1.52 2006/08/29 07:25:26 lav Exp $ */
 
 #include <config.h>
 #include "FileSet.h"
@@ -388,6 +388,21 @@ void FileSet::ExcludeDots()
    }
 }
 
+void FileSet::ExcludeUnaccessible()
+{
+   for(int i=0; i<fnum; i++)
+   {
+      if(!(files[i]->defined&FileInfo::MODE) || !(files[i]->defined&FileInfo::TYPE))
+	 continue;
+      if((files[i]->filetype==FileInfo::NORMAL    && !(files[i]->mode&0444))
+      || (files[i]->filetype==FileInfo::DIRECTORY && !(files[i]->mode&0444&(files[i]->mode<<2))))
+      {
+	 Sub(i);
+	 i--;
+      }
+   }
+}
+
 bool  FileInfo::SameAs(const FileInfo *fi,int ignore)
 {
    if(defined&NAME && fi->defined&NAME)
