@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileSet.h,v 1.36 2006/02/06 11:00:39 lav Exp $ */
+/* $Id: FileSet.h,v 1.38 2006/08/29 07:25:26 lav Exp $ */
 
 #ifndef FILESET_H
 #define FILESET_H
@@ -133,6 +133,8 @@ private:
    void	 Sub(int);
    bool sorted;
 
+   void add_before(int pos,FileInfo *fi);
+
 public:
    FileSet()
    {
@@ -166,6 +168,7 @@ public:
 
    void	 Exclude(const char *prefix,PatternSet *x);
    void	 ExcludeDots();
+   void	 ExcludeUnaccessible();
 
    void	 rewind() { ind=0; }
    FileInfo *curr();
