@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: Filter.h,v 1.17 2002/07/10 08:48:52 lav Exp $ */
+/* $Id: Filter.h,v 1.23 2005/06/21 14:30:04 lav Exp $ */
 
 #ifndef FILTER_H
 #define FILTER_H
@@ -34,6 +34,8 @@ class FDStream
 public:
    int fd;
    char *name;
+   char *full_name;
+   char *cwd;
    char *error_text;
    const char *status;
 
@@ -45,12 +47,15 @@ public:
    FDStream(int new_fd,const char *new_name);
    virtual ~FDStream();
 
-   void MakeErrorText();
+   void MakeErrorText(int e=0);
    bool NonFatalError(int err);
    void set_status(const char *str) { status=str; }
    void clear_status() { status=0; }
    void CloseFD() { close_fd=true; }
 
+   void SetCwd(const char *);
+   const char *GetCwd() const { return cwd; }
+
    virtual off_t get_size() { return -1; }
    virtual void setmtime(time_t) {}
    virtual bool can_setmtime() { return false; }
@@ -59,7 +64,7 @@ public:
    virtual bool Done() { return true; }
    virtual bool usesfd(int n_fd) { return fd==n_fd; }
    virtual void Kill(int=SIGTERM) {}
-   virtual pid_t GetProcGroup() { return 0; }
+   virtual pid_t GetProcGroup() const { return 0; }
    virtual bool broken() { return false; }
    virtual bool can_seek() { return false; }
 };
@@ -72,8 +77,7 @@ class OutputFilter : public FDStream
    FDStream *second;
    bool delete_second;
    bool stderr_to_stdout;
-
-   char *oldcwd;
+   bool stdout_to_null;
 
    bool closed;
 
@@ -92,15 +96,18 @@ public:
    OutputFilter(ArgV *a,FDStream *second);
    virtual ~OutputFilter();
 
-   void SetCwd(const char *);
    void StderrToStdout() { stderr_to_stdout=true; }
+   void StdoutToNull() { stdout_to_null=true; }
 
    int getfd();
    bool Done();
 
    bool usesfd(int n_fd);
    void Kill(int sig=SIGTERM);
-   pid_t GetProcGroup() { return pg; }
+   pid_t GetProcGroup() const { return pg; }
+   void SetProcGroup(pid_t new_pg) { pg=new_pg; }
+   ProcWait::State GetProcState() { return w->GetState(); }
+   int GetProcExitCode() { return w->GetInfo()>>8; }
 
    bool broken();
 
@@ -126,7 +133,6 @@ class FileStream : public FDStream
 {
    int mode;
 public:
-   char *full_name;
    FileStream(const char *fname,int open_mode);
    ~FileStream();
 
