@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FindJob.h,v 1.18 2005/08/03 07:12:46 lav Exp $ */
+/* $Id: FindJob.h,v 1.19 2006/03/15 11:16:09 lav Exp $ */
 
 #ifndef FINDJOB_H
 #define FINDJOB_H
@@ -72,7 +72,7 @@ class FinderJob : public SessionJob
    PatternSet *exclude;
 
 protected:
-   enum state_t { START_INFO, INFO, LOOP, WAIT, DONE };
+   enum state_t { START_INFO, INFO, LOOP, PROCESSING, WAIT, DONE };
    state_t state;
 
    const char *op;
