@@ -70,15 +70,11 @@ int Fish::Do()
    int fd;
 
    // check if idle time exceeded
-   if(mode==CLOSED && send_buf && idle>0)
+   if(mode==CLOSED && send_buf && idle_timer.Stopped())
    {
-      if(now >= idle_start+idle)
-      {
-	 DebugPrint("---- ",_("Closing idle connection"),1);
-	 Disconnect();
-	 return m;
-      }
-      TimeoutS(idle_start+idle-time_t(now));
+      DebugPrint("---- ",_("Closing idle connection"),1);
+      Disconnect();
+      return m;
    }
 
    if(Error())
@@ -98,9 +94,9 @@ int Fish::Do()
       return m;
 
    if(send_buf)
-      BumpEventTime(send_buf->EventTime());
+      timeout_timer.Reset(send_buf->EventTime());
    if(recv_buf)
-      BumpEventTime(recv_buf->EventTime());
+      timeout_timer.Reset(recv_buf->EventTime());
 
    if((state==FILE_RECV || state==FILE_SEND)
    && rate_limit==0)
@@ -163,7 +159,7 @@ int Fish::Do()
       }
       ssh=new PtyShell(cmd);
       state=CONNECTING;
-      event_time=now;
+      timeout_timer.Reset();
       m=MOVED;
    }
    case CONNECTING:
@@ -289,9 +285,9 @@ usual_return:
    if(m==MOVED)
       return MOVED;
    if(send_buf)
-      BumpEventTime(send_buf->EventTime());
+      timeout_timer.Reset(send_buf->EventTime());
    if(recv_buf)
-      BumpEventTime(recv_buf->EventTime());
+      timeout_timer.Reset(recv_buf->EventTime());
    if(CheckTimeout())
       return MOVED;
 // notimeout_return:
@@ -311,7 +307,7 @@ void Fish::MoveConnectionHere(Fish *o)
    RQ_alloc=o->RQ_alloc; o->RQ_alloc=0;
    RQ_head=o->RQ_head; o->RQ_head=0;
    RQ_tail=o->RQ_tail; o->RQ_tail=0;
-   BumpEventTime(o->event_time);
+   timeout_timer.Reset(o->timeout_timer);
    set_real_cwd(o->real_cwd);
    o->set_real_cwd(0);
    state=CONNECTED;
@@ -440,53 +436,6 @@ void Fish::Send(const char *format,...)
    send_buf->Put(str);
 }
 
-const char *Fish::shell_encode(const char *string)
-{
-   if(!string)
-      return 0;
-
-   int c;
-   static char *result=0;
-   char *r;
-   const char *s;
-
-   result = (char*)xrealloc (result, 2 + 2 * strlen (string) + 1);
-
-   r = result;
-   if(string[0]=='-' || string[0]=='~')
-   {
-      *r++='.';
-      *r++='/';
-   }
-
-   for (s = string; s && (c = *s); s++)
-   {
-      switch (c)
-      {
-      case '\'':
-      case '(': case ')':
-      case '!': case '{': case '}':		/* reserved words */
-      case '^':
-      case '$': case '`':			/* expansion chars */
-      case '*': case '[': case '?': case ']':	/* globbing chars */
-      case ' ': case '\t': case '\n':		/* IFS white space */
-      case '"': case '\\':		/* quoting chars */
-      case '|': case '&': case ';':		/* shell metacharacters */
-      case '<': case '>':
-      case '#':				/* comment char */
-	 *r++ = '\\';
-	 *r++ = c;
-	 break;
-      default:
-	 *r++ = c;
-	 break;
-      }
-   }
-
-   *r = '\0';
-   return (result);
-}
-
 void Fish::SendArrayInfoRequests()
 {
    for(int i=array_ptr; i<array_cnt; i++)
@@ -564,10 +513,23 @@ void Fish::SendMethod()
 	 SetError(NO_FILE,"Have to know file size before upload");
 	 break;
       }
-      // dd pays attension to read boundaries and reads wrong number
-      // of bytes when ibs>1. Have to use the inefficient ibs=1.
       if(entity_size>0)
       {
+	 Send("#STOR %lld %s\n"
+	      "rest=%lld;file=%s;:>$file;echo '### 001';"
+	      "if echo 1|head -c 1 -q ->/dev/null 2>&1;then "
+		  "head -c $rest -q -|(cat>$file;cat>/dev/null);"
+	      "else while [ $rest -gt 0 ];do "
+		  "bs=4096;cnt=`expr $rest / $bs`;"
+		  "[ $cnt -eq 0 ] && { cnt=1;bs=$rest; }; "
+		  "n=`dd ibs=$bs count=$cnt 2>/dev/null|tee -a $file|wc -c`;"
+		  "[ \"$n\" -le 0 ] && exit;"
+		  "rest=`expr $rest - $n`; "
+	      "done;fi;echo '### 200'\n",
+	    (long long)entity_size,e,(long long)entity_size,e);
+#if 0
+	 // dd pays attension to read boundaries and reads wrong number
+	 // of bytes when ibs>1. Have to use the inefficient ibs=1.
 	 Send("#STOR %lld %s\n"
 	      ">%s;echo '### 001';"
 	      "dd ibs=1 count=%lld 2>/dev/null"
@@ -576,6 +538,7 @@ void Fish::SendMethod()
 	      e,
 	      (long long)entity_size,
 	      e);
+#endif
       }
       else
       {
@@ -764,7 +727,7 @@ int Fish::HandleReplies()
       PropagateHomeAuto();
       if(!home)
 	 set_home(home_auto);
-      LsCache::SetDirectory(this, home, true);
+      cache->SetDirectory(this, home, true);
       break;
    case EXPECT_CWD:
       p=PopDirectory();
@@ -776,7 +739,7 @@ int Fish::HandleReplies()
 	    cwd.Set(p);
 	    eof=true;
 	 }
-	 LsCache::SetDirectory(this,p,true);
+	 cache->SetDirectory(this,p,true);
       }
       else
 	 SetError(NO_FILE,message);
@@ -1140,7 +1103,7 @@ const char *Fish::CurrentStatus()
    return "";
 }
 
-bool Fish::SameSiteAs(FileAccess *fa)
+bool Fish::SameSiteAs(const FileAccess *fa) const
 {
    if(!SameProtoAs(fa))
       return false;
@@ -1149,7 +1112,7 @@ bool Fish::SameSiteAs(FileAccess *fa)
    && !xstrcmp(user,o->user) && !xstrcmp(pass,o->pass));
 }
 
-bool Fish::SameLocationAs(FileAccess *fa)
+bool Fish::SameLocationAs(const FileAccess *fa)	const
 {
    if(!SameSiteAs(fa))
       return false;
@@ -1182,7 +1145,7 @@ void Fish::Reconfig(const char *name)
    if(!xstrcmp(name,"fish:charset") && recv_buf && send_buf)
    {
       if(!IsSuspended())
-	 LsCache::TreeChanged(this,"/");
+	 cache->TreeChanged(this,"/");
       const char *charset=ResMgr::Query("fish:charset",hostname);
       if(charset && *charset)
       {
@@ -1233,7 +1196,7 @@ int FishDirList::Do()
       const char *cache_buffer=0;
       int cache_buffer_size=0;
       int err;
-      if(use_cache && LsCache::Find(session,pattern,FA::LONG_LIST,&err,
+      if(use_cache && FileAccess::cache->Find(session,pattern,FA::LONG_LIST,&err,
 				    &cache_buffer,&cache_buffer_size))
       {
 	 if(err)
@@ -1250,8 +1213,8 @@ int FishDirList::Do()
 	 session->Open(pattern,FA::LONG_LIST);
 	 ((Fish*)session)->DontEncodeFile();
 	 ubuf=new IOBufferFileAccess(session);
-	 if(LsCache::IsEnabled())
-	    ubuf->Save(LsCache::SizeLimit());
+	 if(FileAccess::cache->IsEnabled(session->GetHostName()))
+	    ubuf->Save(FileAccess::cache->SizeLimit());
       }
    }
 
@@ -1261,7 +1224,7 @@ int FishDirList::Do()
    if(b==0) // eof
    {
       buf->PutEOF();
-      LsCache::Add(session,pattern,FA::LONG_LIST,FA::OK,ubuf);
+      FileAccess::cache->Add(session,pattern,FA::LONG_LIST,FA::OK,ubuf);
       return MOVED;
    }
 
@@ -1343,7 +1306,7 @@ static FileSet *ls_to_FileSet(const char *b,int len)
    return set;
 }
 
-FileSet *Fish::ParseLongList(const char *b,int len,int *err)
+FileSet *Fish::ParseLongList(const char *b,int len,int *err) const
 {
    if(err)
       *err=0;
