@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FtpDirList.h,v 1.6 2001/11/15 17:06:49 lav Exp $ */
+/* $Id: FtpDirList.h,v 1.9 2005/06/22 08:04:19 lav Exp $ */
 
 #ifndef FTPDIRLIST_H
 #define FTPDIRLIST_H
@@ -26,20 +26,23 @@
 class FtpDirList : public DirList
 {
    FileAccess *session;
-   Buffer *ubuf;
+   IOBuffer *ubuf;
    char *pattern;
 
    bool TryEPLF(const char *line,int len);
+   bool TryMLSD(const char *line,int len);
    bool TryColor(const char *line,int len);
 
+   void FormatGeneric(class FileInfo *);
+
 public:
    FtpDirList(ArgV *a,FileAccess *fa);
    ~FtpDirList();
    const char *Status();
    int Do();
 
-   void Suspend();
-   void Resume();
+   void SuspendInternal();
+   void ResumeInternal();
 };
 
 #endif//FTPDIRLIST_H
