@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: LocalAccess.cc,v 1.51 2006/06/13 14:35:38 lav Exp $ */
+/* $Id: LocalAccess.cc,v 1.51.2.1 2007/03/26 07:00:39 lav Exp $ */
 
 #include <config.h>
 #include <errno.h>
@@ -674,12 +674,12 @@ DirList *LocalAccess::MakeDirList(ArgV *a)
 
 #include "ArgV.h"
 LocalDirList::LocalDirList(ArgV *a,const char *cwd)
-   : DirList(a)
+   : DirList(0)
 {
    fg_data=0;
    a->setarg(0,"ls");
    a->insarg(1,"-l");
-   InputFilter *f=new InputFilter(a);
+   InputFilter *f=new InputFilter(a); // a is consumed.
    f->SetCwd(cwd);
    ubuf=new IOBufferFDStream(f,IOBuffer::GET);
 }
