@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-2004 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2005 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: MirrorJob.h,v 1.44 2005/11/30 12:31:53 lav Exp $ */
+/* $Id: MirrorJob.h,v 1.46 2006/08/29 07:25:27 lav Exp $ */
 
 #ifndef MIRRORJOB_H
 #define MIRRORJOB_H
@@ -112,10 +112,9 @@ class MirrorJob : public Job
    FILE *script;
    bool script_only;
    bool script_needs_closing;
-
    bool use_cache;
-
    bool remove_source_files;
+   bool skip_noaccess;
 
    int parallel;
    int pget_n;
@@ -182,6 +181,7 @@ public:
 
    void  UseCache(bool u) { use_cache=u; }
    void	 RemoveSourceFiles() { remove_source_files=true; }
+   void	 SkipNoAccess() { skip_noaccess=true; }
 
    void  SetParallel(int p) { parallel=p; }
    void  SetPGet(int n) { pget_n=n; }
