@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: NetAccess.cc,v 1.80 2006/02/06 10:57:26 lav Exp $ */
+/* $Id: NetAccess.cc,v 1.87 2006/07/27 07:44:54 lav Exp $ */
 
 #include <config.h>
 
@@ -55,11 +55,10 @@
 void NetAccess::Init()
 {
    resolver=0;
-   idle=0;
-   idle_start=now;
+   idle_timer.SetResource("net:idle",0);
+   timeout_timer.SetResource("net:timeout",0);
    max_retries=0;
    max_persist_retries=0;
-   retries=0;
    persist_retries=0;
    socket_buffer=0;
    socket_maxseg=0;
@@ -71,7 +70,6 @@ void NetAccess::Init()
    reconnect_interval=30;  // retry with 30 second interval
    reconnect_interval_multiplier=1.2;
    reconnect_interval_max=300;
-   timeout=600;		   // 10 minutes with no events = reconnect
 
    proxy=proxy_proto=0;
    proxy_port=0;
@@ -82,7 +80,7 @@ void NetAccess::Init()
    connection_limit=0;	// no limit.
    connection_takeover=false;
 
-   home_auto=xstrdup(FindHomeAuto());
+   home_auto=0;
 
    Reconfig(0);
 }
@@ -118,7 +116,6 @@ void NetAccess::Reconfig(const char *name)
 
    const char *c=hostname;
 
-   timeout = TimeInterval(ResMgr::Query("net:timeout",c)).Seconds();
    reconnect_interval = ResMgr::Query("net:reconnect-interval-base",c);
    reconnect_interval_multiplier = ResMgr::Query("net:reconnect-interval-multiplier",c);
    if(reconnect_interval_multiplier<1)
@@ -126,7 +123,6 @@ void NetAccess::Reconfig(const char *name)
    reconnect_interval_max = ResMgr::Query("net:reconnect-interval-max",c);
    if(reconnect_interval_max<reconnect_interval)
       reconnect_interval_max=reconnect_interval;
-   idle = ResMgr::Query("net:idle",c);
    max_retries = ResMgr::Query("net:max-retries",c);
    max_persist_retries = ResMgr::Query("net:persist-retries",c);
    socket_buffer = ResMgr::Query("net:socket-buffer",c);
@@ -163,7 +159,7 @@ void NetAccess::ReuseAddress(int sock)
 {
    setsockopt(sock,SOL_SOCKET,SO_REUSEADDR,(char*)&one,sizeof(one));
 }
-void NetAccess::SetSocketBuffer(int sock,int socket_buffer)
+void NetAccess::SetSocketBuffer(int sock)
 {
    if(socket_buffer==0)
       return;
@@ -172,7 +168,7 @@ void NetAccess::SetSocketBuffer(int sock,int socket_buffer)
    if(-1==setsockopt(sock,SOL_SOCKET,SO_RCVBUF,(char*)&socket_buffer,sizeof(socket_buffer)))
       Log::global->Format(1,"setsockopt(SO_RCVBUF,%d): %s\n",socket_buffer,strerror(errno));
 }
-void NetAccess::SetSocketMaxseg(int sock,int socket_maxseg)
+void NetAccess::SetSocketMaxseg(int sock)
 {
 #ifndef SOL_TCP
 # define SOL_TCP IPPROTO_TCP
@@ -184,15 +180,6 @@ void NetAccess::SetSocketMaxseg(int sock,int socket_maxseg)
       Log::global->Format(1,"setsockopt(TCP_MAXSEG,%d): %s\n",socket_maxseg,strerror(errno));
 #endif
 }
-void  NetAccess::SetSocketBuffer(int sock)
-{
-   SetSocketBuffer(sock,socket_buffer);
-}
-
-void  NetAccess::SetSocketMaxseg(int sock)
-{
-   SetSocketBuffer(sock,socket_maxseg);
-}
 
 const char *NetAccess::SocketNumericAddress(const sockaddr_u *u)
 {
@@ -337,6 +324,57 @@ int NetAccess::SocketBuffered(int sock)
    return 0;
 #endif
 }
+int NetAccess::CheckHangup(const struct pollfd *pfd,int num)
+{
+   for(int i=0; i<num; i++)
+   {
+#ifdef SO_ERROR
+      char  str[256];
+      int   s_errno=0;
+      socklen_t len;
+
+      errno=0;
+
+// Where does the error number go - to errno or to the pointer?
+// It seems that to errno, but if the pointer is NULL it dumps core.
+// (solaris 2.5)
+// It seems to be different on glibc 2.0 - check both errno and s_errno
+
+      len=sizeof(s_errno);
+      getsockopt(pfd[i].fd,SOL_SOCKET,SO_ERROR,(char*)&s_errno,&len);
+      if(errno==ENOTSOCK)
+	 return 0;
+      if(errno!=0 || s_errno!=0)
+      {
+	 sprintf(str,_("Socket error (%s) - reconnecting"),
+				    strerror(errno?errno:s_errno));
+	 DebugPrint("**** ",str,0);
+	 return 1;
+      }
+#endif /* SO_ERROR */
+      if(pfd[i].revents&POLLERR)
+      {
+	 DebugPrint("**** ","POLLERR",0);
+	 return 1;
+      }
+   } /* end for */
+   return 0;
+}
+int NetAccess::Poll(int fd,int ev)
+{
+   struct pollfd pfd;
+   pfd.fd=fd;
+   pfd.events=ev;
+   pfd.revents=0;
+   int res=poll(&pfd,1,0);
+   if(res<1)
+      return 0;
+   if(CheckHangup(&pfd,1))
+      return -1;
+   if(pfd.revents)
+      timeout_timer.Reset();
+   return pfd.revents;
+}
 
 void NetAccess::SayConnectingTo()
 {
@@ -401,17 +439,16 @@ void NetAccess::HandleTimeout()
 {
    DebugPrint("**** ",_("Timeout - reconnecting"),0);
    Disconnect();
-   event_time=now;
+   timeout_timer.Reset();
 }
 
 bool NetAccess::CheckTimeout()
 {
-   if(time_t(now) >= event_time+timeout)
+   if(timeout_timer.Stopped())
    {
       HandleTimeout();
       return(true);
    }
-   TimeoutS(timeout-(time_t(now)-event_time));
    return(false);
 }
 
@@ -436,13 +473,14 @@ void NetAccess::ResetLocationData()
    Disconnect();
    ClearPeer();
    super::ResetLocationData();
+   timeout_timer.SetResource("net:timeout",hostname);
+   idle_timer.SetResource("net:idle",hostname);
 }
 
-void NetAccess::ConnectVerify()
+void NetAccess::Open(const char *fn,int mode,off_t offs)
 {
-   if(peer)
-      return;
-   mode=CONNECT_VERIFY;
+   timeout_timer.Reset();
+   super::Open(fn,mode,offs);
 }
 
 int NetAccess::Resolve(const char *defp,const char *ser,const char *pr)
@@ -644,10 +682,7 @@ void NetAccess::TrySuccess()
 void NetAccess::Close()
 {
    if(mode!=CLOSED)
-   {
-      idle_start=now;
-      TimeoutS(idle);
-   }
+      idle_timer.Reset();
 
    TrySuccess();
 
@@ -715,7 +750,7 @@ do_again:
       const char *cache_buffer=0;
       int cache_buffer_size=0;
       int err;
-      if(use_cache && LsCache::Find(session,"",mode,&err,
+      if(use_cache && FileAccess::cache->Find(session,"",mode,&err,
 				    &cache_buffer,&cache_buffer_size))
       {
 	 if(err)
@@ -738,8 +773,8 @@ do_again:
 	 session->UseCache(use_cache);
 	 ubuf=new IOBufferFileAccess(session);
 	 ubuf->SetSpeedometer(new Speedometer());
-	 if(LsCache::IsEnabled())
-	    ubuf->Save(LsCache::SizeLimit());
+	 if(FileAccess::cache->IsEnabled(session->GetHostName()))
+	    ubuf->Save(FileAccess::cache->SizeLimit());
 	 Roll(session);
 	 Roll(ubuf);
       }
@@ -749,7 +784,7 @@ do_again:
    {
       if(ubuf->Error())
       {
-	 LsCache::Add(session,"",mode,session->GetErrorCode(),ubuf);
+	 FileAccess::cache->Add(session,"",mode,session->GetErrorCode(),ubuf);
 	 if(mode==FA::MP_LIST)
 	 {
 	    mode=FA::LONG_LIST;
@@ -767,7 +802,7 @@ do_again:
       if(!ubuf->Eof())
 	 return m;
 
-      LsCache::Add(session,"",mode,FA::OK,ubuf);
+      FileAccess::cache->Add(session,"",mode,FA::OK,ubuf);
 
       // now we have all the index in ubuf; parse it.
       const char *b;
@@ -779,6 +814,7 @@ do_again:
       FileSet *set=Parse(b,len);
       if(set)
       {
+	 bool need_resort=false;
 	 set->rewind();
 	 for(file=set->curr(); file!=0; file=set->next())
 	 {
@@ -789,8 +825,11 @@ do_again:
 	       file->name=(char*)xrealloc(file->name,len+3);
 	       memmove(file->name+2,file->name,len+1);
 	       memcpy(file->name,"./",2);
+	       need_resort=true;
 	    }
 	 }
+	 if(need_resort && !result)
+	    result=new FileSet; // Merge will sort the names
 	 if(result)
 	 {
 	    result->Merge(set);
