@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: ResMgr.h,v 1.44 2006/04/19 09:48:04 lav Exp $ */
+/* $Id: ResMgr.h,v 1.49 2006/06/30 14:10:28 lav Exp $ */
 
 #ifndef RESMGR_H
 #define RESMGR_H
@@ -33,19 +33,31 @@ typedef const char *ResValValid(char **value);
 typedef const char *ResClValid(char **closure);
 
 class ResValue;
-class ResDecl;
+
+struct ResType
+{
+   const char *name;
+   const char *defvalue;
+   ResValValid *val_valid;
+   ResClValid *closure_valid;
+   ResType *next;
+   ~ResType();
+
+   ResValue Query(const char *closure) const;
+   bool QueryBool(const char *closure) const;
+};
 
 class ResMgr
 {
    static bool class_inited;
-   friend class ResDecl;
+   friend class ResType;
 public:
    class Resource
    {
       friend class ResMgr;
-      friend class ResDecl;
+      friend class ResType;
 
-      const ResDecl *type;
+      const ResType *type;
       char *value;
       char *closure;
 
@@ -53,7 +65,7 @@ public:
 
       bool ClosureMatch(const char *cl_data);
 
-      Resource(Resource *next,const ResDecl *type,
+      Resource(Resource *next,const ResType *type,
 	       char *closure,char *value)
       {
 	 this->type=type;
@@ -70,10 +82,12 @@ public:
 
 private:
    static Resource *chain;
-   static ResDecl *type_chain;
+   static ResType *type_chain;
 
 public:
+   static void AddType(ResType *t) { t->next=type_chain; type_chain=t; }
    static const char *QueryNext(const char *name,const char **closure,Resource **ptr);
+   static const char *SimpleQuery(const ResType *type,const char *closure);
    static const char *SimpleQuery(const char *name,const char *closure);
    static ResValue Query(const char *name,const char *closure);
    static bool QueryBool(const char *name,const char *closure);
@@ -85,7 +99,8 @@ public:
    };
 
    static int VarNameCmp(const char *name1,const char *name2);
-   static const char *FindVar(const char *name,ResDecl **type);
+   static const char *FindVar(const char *name,const ResType **type);
+   static const ResType *FindRes(const char *name);
    static const char *Set(const char *name,const char *closure,const char *value);
 
    static char *Format(bool with_defaults,bool only_defaults);
@@ -118,23 +133,17 @@ public:
    static int VResourceCompare(const void *a,const void *b);
 };
 
-class ResDecl
+class ResDecl : public ResType
 {
-   friend class ResMgr;
-
-   ResDecl *next;
-   ResValValid *val_valid;
-   ResClValid *closure_valid;
 public:
-   const char *name;
-   char *defvalue;
-
-   ResDecl(const char *name,const char *defvalue,
-	   ResValValid *val_valid,ResClValid *closure_valid=0);
-   ~ResDecl();
-
-   ResValue Query(const char *closure);
-   bool QueryBool(const char *closure);
+   ResDecl(const char *a_name,const char *a_defvalue,
+	   ResValValid *a_val_valid,ResClValid *a_closure_valid=0);
+};
+class ResDecls
+{
+public:
+   ResDecls(ResType *array);
+   ResDecls(ResType *r1,ResType *r2,...);
 };
 
 class ResValue
@@ -180,7 +189,7 @@ public:
       }
 };
 
-inline bool ResDecl::QueryBool(const char *closure)
+inline bool ResType::QueryBool(const char *closure) const
 {
    return Query(closure).to_bool();
 }
@@ -189,21 +198,19 @@ inline bool ResMgr::QueryBool(const char *name,const char *closure)
    return Query(name,closure).to_bool();
 }
 
-class TimeInterval : public TimeDiff
+class TimeIntervalR : public TimeInterval
 {
-   bool infty;
    const char *error_text;
    void init(const char *);
 public:
    void Set(const char *s) { init(s); }
-   TimeInterval(const char *s) { init(s); }
-   TimeInterval(ResValue r) { init(r); }
-   TimeInterval(time_t i) : TimeDiff(i,0) { infty=false; error_text=0; }
-   TimeInterval(const TimeDiff &d) : TimeDiff(d) { infty=false; error_text=0; }
+   TimeIntervalR() { error_text=0; }
+   TimeIntervalR(const char *s) : TimeInterval(0,0) { init(s); }
+   TimeIntervalR(ResValue r) : TimeInterval(0,0) { init(r); }
+   TimeIntervalR(time_t s,int ms=0) : TimeInterval(s,ms) { error_text=0; }
+   TimeIntervalR(const TimeDiff &d) : TimeInterval(d) { error_text=0; }
    bool Error() const { return error_text!=0; };
    const char *ErrorText() const { return error_text; }
-
-   bool IsInfty() const { return infty; }
 };
 
 class Range
