@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: SFtp.h,v 1.20 2006/02/06 11:00:40 lav Exp $ */
+/* $Id: SFtp.h,v 1.21 2006/06/13 14:35:41 lav Exp $ */
 
 #ifndef SFTP_H
 #define SFTP_H
@@ -243,7 +243,7 @@ private:
    PtyShell *ssh;
 
    void Disconnect();
-   int IsConnected()
+   int IsConnected() const
       {
 	 if(state==DISCONNECTED)
 	    return 0;
@@ -774,9 +774,9 @@ public:
    SFtp(const SFtp*);
    ~SFtp();
 
-   const char *GetProto() { return "sftp"; }
+   const char *GetProto() const { return "sftp"; }
 
-   FileAccess *Clone() { return new SFtp(this); }
+   FileAccess *Clone() const { return new SFtp(this); }
    static FileAccess *New();
 
    int Do();
@@ -791,8 +791,8 @@ public:
 
    void Reconfig(const char *name=0);
 
-   bool SameSiteAs(FileAccess *fa);
-   bool SameLocationAs(FileAccess *fa);
+   bool SameSiteAs(const FileAccess *fa) const;
+   bool SameLocationAs(const FileAccess *fa) const;
 
    DirList *MakeDirList(ArgV *args);
    Glob *MakeGlob(const char *pattern);
