@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: SMTask.cc,v 1.42 2006/05/13 05:46:10 lav Exp $ */
+/* $Id: SMTask.cc,v 1.48 2006/09/27 07:03:38 lav Exp $ */
 
 #include <config.h>
 #include <assert.h>
@@ -30,6 +30,7 @@
 #endif
 
 #include "SMTask.h"
+#include "Timer.h"
 #include "misc.h"
 
 SMTask	 *SMTask::chain=0;
@@ -107,7 +108,15 @@ SMTask::~SMTask()
    printf("delete SMTask %p (count=%d)\n",this,task_count);
 #endif
    task_count--;
-   assert(!running);
+   if(__builtin_expect(running,0))
+   {
+      fprintf(stderr,"SMTask(%p).running=%d\n",this,running);
+      fprintf(stderr,"SMTask stack:");
+      for(int i=0; i<stack_ptr; i++)
+	 fprintf(stderr," %p",stack[i]);
+      fprintf(stderr,"; current=%p\n",current);
+      abort();
+   }
    assert(!ref_count);
    // remove from the chain
    SMTask **scan=&chain;
@@ -120,7 +129,6 @@ SMTask::~SMTask()
       }
       scan=&((*scan)->next);
    }
-   assert(!"SMTask dtor called with unregistered task");
 }
 
 void SMTask::Delete(SMTask *task)
@@ -159,12 +167,11 @@ int SMTask::Roll(SMTask *task)
    return m;
 }
 
-void SMTask::RollAll(int max_time)
+void SMTask::RollAll(const TimeInterval &max_time)
 {
-   time_t time_limit=now.UnixTime()+max_time;
+   Timer limit_timer(max_time);
    do { Schedule(); }
-   while(sched_total.GetTimeout()==0
-	 && (max_time==0 || now<time_limit));
+   while(sched_total.GetTimeout()==0 && !limit_timer.Stopped());
 }
 
 int SMTask::CollectGarbage()
@@ -213,6 +220,10 @@ void SMTask::Schedule()
    // get time once and assume Do() don't take much time
    UpdateNow();
 
+   int timer_timeout=Timer::GetTimeout();
+   if(timer_timeout>=0)
+      sched_total.SetTimeout(timer_timeout);
+
    bool repeat=false;
    scan=chain;
    while(scan)
@@ -256,6 +267,7 @@ void SMTask::Schedule()
 void SMTask::ReconfigAll(const char *name)
 {
    UpdateNow();
+   Timer::ReconfigAll(name);
    for(SMTask *scan=chain; scan; scan=scan->next)
       scan->Reconfig(name);
    sched_total.SetTimeout(0);  // for new values handling
@@ -284,8 +296,8 @@ int SMTask::TaskCount()
 
 void SMTask::Cleanup()
 {
-  CollectGarbage();
-  delete init_task;
+   CollectGarbage();
+   delete init_task;
 }
 
 #include <errno.h>
@@ -324,3 +336,14 @@ bool SMTask::TemporaryNetworkError(int err)
 {
    return temporary_network_error(err);
 }
+
+void SMTask::PrintTasks()
+{
+   for(SMTask *scan=chain; scan; scan=scan->next)
+   {
+      const char *c=scan->GetLogContext();
+      if(!c) c="";
+      printf("%p\t%c%c%c\t%s\n",scan,scan->running?'R':' ',
+	 scan->suspended?'S':' ',scan->deleting?'D':' ',c);
+   }
+}
