@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-2000 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2005 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: bookmark.cc,v 1.12 2005/06/23 06:39:03 lav Exp $ */
+/* $Id: bookmark.cc,v 1.17 2006/02/06 10:57:28 lav Exp $ */
 
 #include <config.h>
 #include "bookmark.h"
@@ -27,6 +27,8 @@
 #include <unistd.h>
 #include "trio.h"
 #include "ResMgr.h"
+#include "misc.h"
+#include "url.h"
 
 #define super KeyValueDB
 
@@ -36,13 +38,14 @@ ResDecl res_auto_sync("bmk:auto-sync","yes",ResMgr::BoolValidate,ResMgr::NoClosu
 
 Bookmark::Bookmark()
 {
-   const char *home=getenv("HOME");
-   if(home==0)
-      home="";
-   const char *add="/.lftp/bookmarks";
-   bm_file=xstrdup(home,+strlen(add));
-   strcat(bm_file,add);
-
+   bm_file=0;
+   const char *home=get_lftp_home();
+   if(home)
+   {
+      const char *add="/bookmarks";
+      bm_file=xstrdup(home,+strlen(add));
+      strcat(bm_file,add);
+   }
    bm_fd=-1;
    stamp=(time_t)-1;
 }
@@ -55,6 +58,8 @@ Bookmark::~Bookmark()
 
 void Bookmark::Refresh()
 {
+   if(!bm_file)
+      return;
    struct stat st;
    if((bm_fd==-1 ? stat(bm_file,&st) : fstat(bm_fd,&st)) == -1)
       return;
@@ -66,6 +71,8 @@ void Bookmark::Refresh()
 void Bookmark::Load()
 {
    super::Empty();
+   if(!bm_file)
+      return;
    if(bm_fd==-1)
    {
       bm_fd=open(bm_file,O_RDONLY);
@@ -86,6 +93,9 @@ void Bookmark::Load()
 static bool auto_sync;
 void Bookmark::PreModify()
 {
+   if(!bm_file)
+      return;
+
    auto_sync=ResMgr::QueryBool("bmk:auto-sync",0);
    if(!auto_sync)
       return;
@@ -104,6 +114,9 @@ void Bookmark::PreModify()
 }
 void Bookmark::PostModify()
 {
+   if(!bm_file)
+      return;
+
    if(!auto_sync)
       return;
 
@@ -111,10 +124,9 @@ void Bookmark::PostModify()
    lseek(bm_fd,0,SEEK_SET);
 
 #ifdef HAVE_FTRUNCATE
-   ftruncate(bm_fd,0);
-#else
-   close(open(bm_file,O_WRONLY|O_TRUNC));
+   if(ftruncate(bm_fd,0)==-1) // note the following statement
 #endif
+   close(open(bm_file,O_WRONLY|O_TRUNC));
 
    super::Write(bm_fd);
    bm_fd=-1;   // Write closes file
@@ -122,6 +134,8 @@ void Bookmark::PostModify()
 
 void Bookmark::UserSave()
 {
+   if(!bm_file)
+      return;
    Close();
    bm_fd=open(bm_file,O_RDWR|O_CREAT|O_TRUNC,0600);
    if(bm_fd==-1)
@@ -189,37 +203,8 @@ char *Bookmark::Format()
    return super::Format();
 }
 
-static const char *hide_password(const char *url)
-{
-   const char *scan=strstr(url,"://");
-   if(!scan)
-      return url;
-
-   scan+=3;
-
-   const char *at=strchr(scan,'@');
-   if(!at)
-      return url;
-
-   const char *colon=strchr(scan,':');
-   if(!colon || colon>at)
-      return url;
-
-   const char *slash=strchr(scan,'/');
-   if(slash && slash<at)
-      return url;
-
-   static char *buf;
-   static int buf_alloc;
-   int need=strlen(url)+5;
-   if(buf_alloc<need)
-      buf=(char*)xrealloc(buf,buf_alloc=need);
-   sprintf(buf,"%.*sXXXX%s",colon+1-url,url,at);
-   return buf;
-}
-
 char *Bookmark::FormatHidePasswords()
 {
    AutoSync();
-   return super::Format(hide_password);
+   return super::Format(url::hide_password);
 }
