@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: commands.cc,v 1.259 2006/08/07 08:55:21 lav Exp $ */
+/* $Id: commands.cc,v 1.261.2.2 2007/02/26 15:09:54 lav Exp $ */
 
 #include <config.h>
 
@@ -140,7 +140,7 @@ const struct CmdExec::cmd_rec CmdExec::static_cmd_table[]=
 	 "  stat        - print cache status (default)\n"
 	 "  on|off      - turn on/off caching\n"
 	 "  flush       - flush cache\n"
-	 "  size <lim>  - set memory limit, -1 means unlimited\n"
+	 "  size <lim>  - set memory limit\n"
 	 "  expire <Nx> - set cache expiration time to N seconds (x=s)\n"
 	 "                minutes (x=m) hours (x=h) or days (x=d)\n")},
    {"cat",     cmd_cat,    N_("cat [-b] <files>"),
@@ -909,10 +909,17 @@ Job *CmdExec::builtin_open()
 	    delete url;
 	    url=new ParsedURL(u);
 	 }
-	 if(user)
+	 if(user || port)
 	 {
 	    url->user=user;
 	    url->pass=pass;
+	    if(user)
+	    {
+	       url->user=user;
+	       url->pass=pass;
+	    }
+	    if(port)
+	       url->port=port;
 	    char *host1=url->Combine();
 	    delete url;
 	    url=new ParsedURL(host1);
