@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-2000 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2005 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: history.cc,v 1.12 2005/08/03 07:12:48 lav Exp $ */
+/* $Id: history.cc,v 1.17 2006/02/06 10:57:30 lav Exp $ */
 
 #include <config.h>
 #include <sys/types.h>
@@ -28,6 +28,7 @@
 #include "trio.h"
 #include "history.h"
 #include "url.h"
+#include "misc.h"
 
 #define super KeyValueDB
 
@@ -37,13 +38,14 @@ History::History()
    stamp=0;
    fd=-1;
    modified=false;
-
-   const char *home=getenv("HOME");
-   if(home==0)
-      home="";
-   const char *add="/.lftp/cwd_history";
-   file=xstrdup(home,+strlen(add));
-   strcat(file,add);
+   file=0;
+   const char *home=get_lftp_home();
+   if(home)
+   {
+      const char *add="/cwd_history";
+      file=xstrdup(home,+strlen(add));
+      strcat(file,add);
+   }
 }
 
 History::~History()
@@ -70,7 +72,8 @@ const char *History::extract_url(const char *res)
       buf=(char*)xrealloc(buf,buf_len=len+64);
 
    strcpy(buf,url);
-   url::decode_string(buf);
+   if(!url::is_url(buf))
+      url::decode_string(buf);
 
    return buf;
 }
@@ -100,6 +103,8 @@ const char *History::Lookup(FileAccess *s)
 
 void History::Refresh()
 {
+   if(!file)
+      return;
    struct stat st;
    if((fd==-1 ? stat(file,&st) : fstat(fd,&st)) == -1)
       return;
@@ -112,6 +117,8 @@ void History::Load()
 {
    if(full)
       full->Empty();
+   if(!file)
+      return;
    if(fd==-1)
    {
       fd=open(file,O_RDONLY);
@@ -161,6 +168,8 @@ void History::Set(FileAccess *s,const FileAccess::Path &cwd)
 void History::Save()
 {
    Close();
+   if(!file)
+      return;
    if(!modified)
       return;
    fd=open(file,O_RDWR|O_CREAT,0600);
@@ -200,10 +209,9 @@ void History::Save()
    lseek(fd,0,SEEK_SET);
 
 #ifdef HAVE_FTRUNCATE
-   ftruncate(fd,0);
-#else
-   close(open(file,O_WRONLY|O_TRUNC));
+   if(ftruncate(fd,0)==-1) // note the following statement
 #endif
+   close(open(file,O_WRONLY|O_TRUNC));
 
    full->Write(fd);
    fd=-1;   // Write closes file
