@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: history.h,v 1.2 2000/11/05 14:38:06 lav Exp $ */
+/* $Id: history.h,v 1.3 2005/08/03 07:12:48 lav Exp $ */
 
 #ifndef HISTORY_H
 #define HISTORY_H
@@ -43,7 +43,8 @@ class History : public KeyValueDB
    time_t extract_stamp(const char *res);
 
 public:
-   void Set(FileAccess *s,const char *cwd);
+   void Set(FileAccess *s,const FileAccess::Path &p);
+   void Set(FileAccess *s) { Set(s,s->GetCwd()); }
    const char *Lookup(FileAccess *s);
    void Save();
    History();
